#!/bin/bash
#
# nohup ./data_transfer.sh >& expid.log &
#

##################################
####  User Defined Variables  #### 
##################################

dst1=/cfunas/exp/ecearth           # store logfiles, MM*, REST*
dst2=/cfunas/exp/ecearth/gribfiles # store ICM*

plt= # choose platform (ithaca, mn)
expid= # supply expid
sdates="" # supply list of start dates
members="" # supply list of members

remove=TRUE # remove output from source
if [[ $remove == TRUE ]]; then
 RSYNC="rsync -acv --remove-sent-files"
else
 RSYNC="rsync -acv"
fi
#####  End of User Defined Dariables  ####

#################################
####  User Defined Funtions  #### 
#################################

function transfer1(){
 fdst=$1/$expid/$s/$m/$2
 for l in $list; do
  echo "tranfering file ... ${plt}:$l $fdst"
  $RSYNC ${plt}:${l} $fdst
  echo "done."
  echo
  echo
 done
}

function transfer2(){
 fdst=$1/$expid/$s/$m/$2
 for l in $list; do
  echo "tranfering file ... ${hsm}:$l $tmp"
  $sshplt rsync -acv ${hsm}:${l} $tmp
  nl=`basename $l`
  echo "tranfering file ... ${plt}:${tmp}/$nl $fdst"
  rsync -acv --remove-sent-files ${plt}:${tmp}/$nl $fdst
  if [[ $? -eq 0 && $remove == TRUE ]]; then
   $sshplthsm rm -f $l
  fi
  echo "done."
  echo
  echo
 done
}
####  End of the User Defined Functions  #### 

###################################
####  Main Part of the Script  ####
###################################

date
echo "expid is: $expid"
echo "start dates: $sdates"
echo "members per start date: $members"

for s in $sdates; do
 for m in $members; do
  mkdir -p $dst1/$expid/$s/$m/restarts
  mkdir -p $dst1/$expid/$s/$m/outputs
  case $plt in
   ithaca)
    sshplt="ssh $plt"
    src=/share/data/cfu/exp
    #logfiles*
    list=`$sshplt ls -1 $src/$expid/$s/$m/logfiles*`
    transfer1 $dst1 ""
    #MM*
    list=`$sshplt ls -1 $src/$expid/$s/$m/outputs/MM?_*`
    transfer1 $dst1 outputs
    #REST*
    list=`$sshplt ls -1 $src/$expid/$s/$m/restarts/REST?_*`
    transfer1 $dst1 restarts
    #ICM*
    list=`$sshplt ls -1 $src/$expid/$s/$m/outputs/ICM*`
    listwc=`$sshplt ls -1 $src/$expid/$s/$m/outputs/ICM* | wc -l`
    if [[ $listwc -gt 0 ]]; then
     mkdir -p $dst2/$expid/$s/$m/outputs/
     transfer1 $dst2 outputs
    fi
   ;;
   mn)
    sshplt="ssh $plt"
    hsm="login8"
    sshplthsm="ssh $plt ssh $hsm"
    src=/HSM/ecm86/exp
    username=`ssh $plt env | grep -w USER | cut -d '=' -f2`
    tmp=/gpfs/scratch/ecm86/$username/${expid}_data_transfer
    $sshplt mkdir -p $tmp
    #logfiles*
    list=`$sshplthsm ls -1 $src/$expid/$s/$m/logfiles*`
    transfer2 $dst1 ""
    #MM*
    list=`$sshplthsm ls -1 $src/$expid/$s/$m/outputs/MM?_*`
    transfer2 $dst1 outputs
    #REST*
    list=`$sshplthsm ls -1 $src/$expid/$s/$m/restarts/REST?_*`
    transfer2 $dst1 restarts
    #ICM*
    list=`$sshplthsm ls -1 $src/$expid/$s/$m/outputs/ICM*`
    listwc=`$sshplthsm ls -1 $src/$expid/$s/$m/outputs/ICM* | wc -l`
    if [[ $listwc -gt 0 ]]; then
     mkdir -p $dst2/$expid/$s/$m/outputs/
     transfer2 $dst2 outputs
    fi
    $sshplt rm -rf $tmp
   ;;
   *) echo "$plt is not a valid machine"
   ;;
  esac
 done
done
date
####  End of the Main Part of Script  ####
